@@ -39,6 +39,8 @@ void SearchModel::search(const QString &queryString)
 {
     auto url = m_account->apiUrl("/api/v2/search");
     url.setQuery({{"q", queryString}});
+    setLoading(true);
+    setLoaded(false);
     m_account->get(url, true, this, [this](QNetworkReply *reply) {
         const auto searchResult = QJsonDocument::fromJson(reply->readAll()).object();
         const auto statuses = searchResult[QStringLiteral("statuses")].toArray();
@@ -67,6 +69,8 @@ void SearchModel::search(const QString &queryString)
             std::back_inserter(m_hashtags),
             [](const QJsonValue &value) -> auto{ return SearchHashtag(value.toObject()); });
         endResetModel();
+        setLoading(false);
+        setLoaded(true);
     });
 }
 
@@ -122,6 +126,8 @@ void SearchModel::clear()
     qDeleteAll(m_statuses);
     m_statuses.clear();
     m_hashtags.clear();
+    setLoading(false);
+    setLoaded(false);
 }
 
 QString SearchModel::labelForType(ResultType sectionType)
@@ -138,7 +144,21 @@ QString SearchModel::labelForType(ResultType sectionType)
     }
 }
 
-SearchHashtag::SearchHashtag(QJsonObject object)
+bool SearchModel::loaded() const
+{
+    return m_loaded;
+}
+
+void SearchModel::setLoaded(bool loaded)
+{
+    if (m_loaded == loaded) {
+        return;
+    }
+    m_loaded = loaded;
+    Q_EMIT loadedChanged();
+}
+
+SearchHashtag::SearchHashtag(const QJsonObject &object)
 {
     m_name = object["name"].toString();
 }
