@@ -11,7 +11,7 @@ class Post;
 class SearchHashtag
 {
 public:
-    explicit SearchHashtag(QJsonObject object);
+    explicit SearchHashtag(const QJsonObject &object);
 
     QString getName() const;
 
@@ -22,6 +22,7 @@ private:
 class SearchModel : public AbstractTimelineModel
 {
     Q_OBJECT
+    Q_PROPERTY(bool loaded READ loaded NOTIFY loadedChanged)
 
 public:
     enum ResultType {
@@ -34,15 +35,22 @@ public:
     explicit SearchModel(QObject *parent = nullptr);
     ~SearchModel();
 
+    bool loaded() const;
+    void setLoaded(bool loaded);
+
     Q_INVOKABLE void search(const QString &queryString);
     Q_INVOKABLE QString labelForType(SearchModel::ResultType sectionType);
+    Q_INVOKABLE void clear();
 
     int rowCount(const QModelIndex &parent) const override;
     QVariant data(const QModelIndex &index, int role) const override;
 
+Q_SIGNALS:
+    void loadedChanged();
+
 private:
-    void clear();
     QList<std::shared_ptr<Identity>> m_accounts;
     QList<Post *> m_statuses;
     QList<SearchHashtag> m_hashtags;
+    bool m_loaded = false;
 };
\ No newline at end of file
